# @property
# def urls():
#      import django
#      if django.VERSION < (1, 9):
#          from .mfa_urls import url_patterns
#          return url_patterns, 'mfa', ''
#      else:
#          from .mfa_urls import url_patterns
#          return url_patterns,'mfa'
#
