<table>
    <tr>
        <th>Browser: </th>
        <td>{{ ua.browser.family }}</td>
    </tr>
    <tr>
        <th>Version: </th>
        <td>{{ ua.browser.version_string }}</td>
    </tr>
    <tr>
        <th>Device: </th>
        <td>{{ ua.device.brand }} / {{ ua.device.model }}</td>
    </tr>
</table>